#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-9hdT4YRJhcAGfee2WP8Wsd
key:                  gtk-strut-0.1.3.2-9hdT4YRJhcAGfee2WP8Wsd
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  0213ccc868d70c3384a275d3a82bdd06
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-9hdT4YRJhcAGfee2WP8Wsd
depends:
    base-4.18.2.1 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    gi-gdk-3.0.29-7NcwwALc21h1MDBHnAZYMG
    gi-gtk-3.0.43-HP04lIH28sOL8ne7gDPlqj
    hslogger-1.3.2.0-KhhAW8rWjeZEGkIjuDbYCZ text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

